pytilities.geometry.verbosevector.VerboseVector

Package pytilities :: Package geometry :: Module verbosevector :: Class VerboseVector |
[hide private]
[frames] | no frames]

# Class VerboseVector

source code

                                         object --+
                                                  |
    attributecollectionbase.AttributeCollectionBase --+
                                                      |
                                                     VerboseVector

Vector wrapper that sends out events.

It supports all attributes of Vector. For Vector specific documentation, see Vector.

Events:

> changed

>   x and/or y value changed

>   Parameters:

>   > `old_tuple` :: (x, y)
>   >   the old x and y values

Instance Methods | [hide private]
__init__(self, *args, **kwargs) Construct a VerboseVector. | source code
move_to(self, *args) | source code
move_by(self, *args) | source code
assign(self, v) | source code
normalize(self) | source code
__iadd__(self, other) | source code
__imul__(self, other) | source code
Inherited from `attributecollectionbase.AttributeCollectionBase`: `__abs__`, `__add__`, `__copy__`, `__delattr__`, `__div__`, `__eq__`, `__floordiv__`, `__getattr__`, `__getitem__`, `__iter__`, `__len__`, `__mul__`, `__neg__`, `__neq__`, `__nonzero__`, `__pos__`, `__rdiv__`, `__rfloordiv__`, `__rmul__`, `__rtruediv__`, `__setattr__`, `__setitem__`, `__str__`, `__sub__`, `__truediv__` Inherited from `attributecollectionbase.AttributeCollectionBase` (private): `_append_attribute_collection` Inherited from `object`: `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
| x
| y
| length
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
Construct a VerboseVector. Parameters: v :: Vector the vector to wrap Overrides: object.__init__

### __iadd__(self, other) | source code
Overrides: attributecollectionbase.AttributeCollectionBase.__iadd__

### __imul__(self, other) | source code
Overrides: attributecollectionbase.AttributeCollectionBase.__imul__

Property Details | [hide private]

### x Get Method: unreachable.x(self) Set Method: unreachable.x(self, value)

### y Get Method: unreachable.y(self) Set Method: unreachable.y(self, value)

### length Get Method: unreachable.length(self) Set Method: unreachable.length(self, value)